summaryrefslogtreecommitdiffstats
path: root/src/definition.h
diff options
context:
space:
mode:
authormueller <mueller@afe2bf4a-e733-0410-8a33-86f594647bc7>1999-12-15 19:42:00 (GMT)
committermueller <mueller@afe2bf4a-e733-0410-8a33-86f594647bc7>1999-12-15 19:42:00 (GMT)
commite37828267bfc6c76a5b01208dcdb676a3aa580f9 (patch)
treee1e96dcb9bbad928271e0546023ea0a9841641b6 /src/definition.h
parent74cc4d70240d09e10c9da94c0537670fc287a85e (diff)
downloadDoxygen-e37828267bfc6c76a5b01208dcdb676a3aa580f9.zip
Doxygen-e37828267bfc6c76a5b01208dcdb676a3aa580f9.tar.gz
Doxygen-e37828267bfc6c76a5b01208dcdb676a3aa580f9.tar.bz2
mods for doxygen-0.49-991205
Diffstat (limited to 'src/definition.h')
-rw-r--r--src/definition.h15
1 files changed, 11 insertions, 4 deletions
diff --git a/src/definition.h b/src/definition.h
index dac9d79..03c422a 100644
--- a/src/definition.h
+++ b/src/definition.h
@@ -77,15 +77,22 @@ class Definition
*/
void addSectionsToDefinition(QList<QCString> *anchorList);
- void setBodyLine(int bl) { bodyLine=bl; }
+ void setBodySegment(int bls,int ble)
+ {
+ startBodyLine=bls;
+ endBodyLine=ble;
+ }
void setBodyDef(FileDef *fd) { bodyDef=fd; }
- int getBodyLine() const { return bodyLine; }
+ int getStartBodyLine() const { return startBodyLine; }
+ int getEndBodyLine() const { return endBodyLine; }
FileDef *getBodyDef() { return bodyDef; }
- void writeSourceRef(OutputList &ol);
+ void writeSourceRef(OutputList &ol,const char *scopeName);
protected:
- int bodyLine; // line number of the definition
+ int startBodyLine; // line number of the start of the definition
+ int endBodyLine; // line number of the end of the definition
FileDef *bodyDef; // file definition containing the function body
+
private:
QCString n; // name of the definition
QCString brief; // brief description